if (interactive()) {
# First, we use magmaRset to create an object which will tell other magmaR
# functions our authentication token (as well as some other optional bits).
# When run in this way, it will ask you to give your token.
magma <- magmaRset()
template <- retrieveTemplate(
target = magma,
projectName = "example")
str(template, max.level = 4)
models <- retrieveModels(
target = magma,
projectName = "example")
print(models)
ids <- retrieveIds(
target = magma,
projectName = "example",
modelName = "rna_seq")
print(ids)
atts <- retrieveAttributes(
target = magma,
projectName = "example",
modelName = "subject")
print(atts)
}
Run the code above in your browser using DataLab